@@ -1,7 +1,11 @@
 package CGI::Push;
 use if $] >= 5.019, 'deprecate';
 
-$CGI::Push::VERSION='4.24';
+my $appease_cpants_kwalitee = q/
+use strict;
+use warnings;
+#/;
+
 use CGI;
 use CGI::Util 'rearrange';
 @ISA = ('CGI');
